@@ -4,15 +4,16 @@
 # list see the documentation:
 # https://www.sphinx-doc.org/en/master/usage/configuration.html
 
+from datetime import date
+
 from sphinx.application import Sphinx
-from sphinx.util.docutils import SphinxDirective
 
 from myst_parser import __version__
 
 # -- Project information -----------------------------------------------------
 
 project = "MyST Parser"
-copyright = "2020, Executable Book Project"
+copyright = f"{date.today().year}, Executable Book Project"
 author = "Executable Book Project"
 version = __version__
 
@@ -29,8 +30,7 @@ extensions = [
     "sphinx.ext.autodoc",
     "sphinx.ext.intersphinx",
     "sphinx.ext.viewcode",
-    "sphinxcontrib.bibtex",
-    "sphinx_panels",
+    "sphinx_design",
     "sphinxext.rediraffe",
     "sphinxcontrib.mermaid",
     "sphinxext.opengraph",
@@ -55,11 +55,13 @@ html_logo = "_static/logo-wide.svg"
 html_favicon = "_static/logo-square.svg"
 html_title = ""
 html_theme_options = {
+    "home_page_in_toc": True,
     "github_url": "https://github.com/executablebooks/MyST-Parser",
     "repository_url": "https://github.com/executablebooks/MyST-Parser",
-    "use_edit_page_button": True,
     "repository_branch": "master",
     "path_to_docs": "docs",
+    "use_repository_button": True,
+    "use_edit_page_button": True,
 }
 # OpenGraph metadata
 ogp_site_url = "https://myst-parser.readthedocs.io/en/latest"
@@ -85,56 +87,32 @@ myst_enable_extensions = [
     "smartquotes",
     "replacements",
     "linkify",
+    "strikethrough",
     "substitution",
     "tasklist",
+    "attrs_image",
 ]
+myst_number_code_blocks = ["typescript"]
 myst_heading_anchors = 2
 myst_footnote_transition = True
 myst_dmath_double_inline = True
-panels_add_bootstrap_css = False
-bibtex_bibfiles = ["examples/references.bib"]
+
 rediraffe_redirects = {
     "using/intro.md": "sphinx/intro.md",
+    "sphinx/intro.md": "intro.md",
     "using/use_api.md": "api/index.md",
+    "api/index.md": "api/reference.rst",
     "using/syntax.md": "syntax/syntax.md",
     "using/syntax-optional.md": "syntax/optional.md",
     "using/reference.md": "syntax/reference.md",
+    "sphinx/reference.md": "configuration.md",
+    "sphinx/index.md": "faq/index.md",
+    "sphinx/use.md": "faq/index.md",
+    "sphinx/faq.md": "faq/index.md",
+    "explain/index.md": "develop/background.md",
 }
 
-
-def run_apidoc(app):
-    """generate apidoc
-
-    See: https://github.com/rtfd/readthedocs.org/issues/1139
-    """
-    import os
-    import shutil
-
-    import sphinx
-    from sphinx.ext import apidoc
-
-    logger = sphinx.util.logging.getLogger(__name__)
-    logger.info("running apidoc")
-    # get correct paths
-    this_folder = os.path.abspath(os.path.dirname(os.path.realpath(__file__)))
-    api_folder = os.path.join(this_folder, "_api")
-    module_path = os.path.normpath(os.path.join(this_folder, "../"))
-    ignore_paths = ["../setup.py", "../conftest.py", "../tests"]
-    ignore_paths = [
-        os.path.normpath(os.path.join(this_folder, p)) for p in ignore_paths
-    ]
-
-    if os.path.exists(api_folder):
-        shutil.rmtree(api_folder)
-    os.mkdir(api_folder)
-
-    argv = ["-M", "--separate", "-o", api_folder, module_path] + ignore_paths
-
-    apidoc.main(argv)
-
-    # we don't use this
-    if os.path.exists(os.path.join(api_folder, "modules.rst")):
-        os.remove(os.path.join(api_folder, "modules.rst"))
+suppress_warnings = ["myst.strikethrough"]
 
 
 intersphinx_mapping = {
@@ -152,11 +130,12 @@ intersphinx_mapping = {
 #     # 'inherited-members': True
 # }
 autodoc_member_order = "bysource"
-
+nitpicky = True
 nitpick_ignore = [
     ("py:class", "docutils.nodes.document"),
     ("py:class", "docutils.nodes.docinfo"),
     ("py:class", "docutils.nodes.Element"),
+    ("py:class", "docutils.nodes.Node"),
     ("py:class", "docutils.nodes.field_list"),
     ("py:class", "docutils.nodes.problematic"),
     ("py:class", "docutils.nodes.pending"),
@@ -165,6 +144,12 @@ nitpick_ignore = [
     ("py:class", "docutils.parsers.rst.directives.misc.Include"),
     ("py:class", "docutils.parsers.rst.Parser"),
     ("py:class", "docutils.utils.Reporter"),
+    ("py:class", "nodes.Element"),
+    ("py:class", "nodes.Node"),
+    ("py:class", "nodes.system_message"),
+    ("py:class", "Directive"),
+    ("py:class", "Include"),
+    ("py:class", "StringList"),
     ("py:class", "DocutilsRenderer"),
     ("py:class", "MockStateMachine"),
 ]
@@ -172,32 +157,13 @@ nitpick_ignore = [
 
 def setup(app: Sphinx):
     """Add functions to the Sphinx setup."""
+    from myst_parser._docs import (
+        DirectiveDoc,
+        DocutilsCliHelpDirective,
+        MystConfigDirective,
+    )
 
-    class DocutilsCliHelpDirective(SphinxDirective):
-        """Directive to print the docutils CLI help."""
-
-        has_content = False
-        required_arguments = 0
-        optional_arguments = 0
-        final_argument_whitespace = False
-        option_spec = {}
-
-        def run(self):
-            """Run the directive."""
-            import io
-
-            from docutils import nodes
-            from docutils.frontend import OptionParser
-
-            from myst_parser.docutils_ import Parser as DocutilsParser
-
-            stream = io.StringIO()
-            OptionParser(
-                components=(DocutilsParser,),
-                usage="myst-docutils-<writer> [options] [<source> [<destination>]]",
-            ).print_help(stream)
-            return [nodes.literal_block("", stream.getvalue())]
-
-    # app.connect("builder-inited", run_apidoc)
     app.add_css_file("custom.css")
+    app.add_directive("myst-config", MystConfigDirective)
     app.add_directive("docutils-cli-help", DocutilsCliHelpDirective)
+    app.add_directive("doc-directive", DirectiveDoc)
