@@ -1,11 +1,13 @@
 """This module provides classes to Mock the core components of the docutils.RSTParser,
 the key difference being that nested parsing treats the text as Markdown not rST.
 """
+from __future__ import annotations
+
 import os
 import re
 import sys
 from pathlib import Path
-from typing import TYPE_CHECKING, List, Optional, Tuple, Type
+from typing import TYPE_CHECKING, Any
 
 from docutils import nodes
 from docutils.parsers.rst import Directive, DirectiveError
@@ -15,10 +17,10 @@ from docutils.parsers.rst.states import Body, Inliner, RSTStateMachine
 from docutils.statemachine import StringList
 from docutils.utils import unescape
 
-from .parse_directives import parse_directive_text
+from .parsers.directives import parse_directive_text
 
 if TYPE_CHECKING:
-    from .docutils_renderer import DocutilsRenderer
+    from .mdit_to_docutils.base import DocutilsRenderer
 
 
 class MockingError(Exception):
@@ -31,28 +33,50 @@ class MockInliner:
     This is parsed to role functions.
     """
 
-    def __init__(self, renderer: "DocutilsRenderer", lineno: int):
+    def __init__(self, renderer: DocutilsRenderer):
+        """Initialize the mock inliner."""
         self._renderer = renderer
+        # here we mock that the `parse` method has already been called
+        # which is where these attributes are set (via the RST state Memo)
         self.document = renderer.document
         self.reporter = renderer.document.reporter
-        if not hasattr(self.reporter, "get_source_and_line"):
-            # TODO this is called by some roles,
-            # but I can't see how that would work in RST?
-            self.reporter.get_source_and_line = lambda l: (self.document["source"], l)
-        self.parent = renderer.current_node
         self.language = renderer.language_module_rst
+        self.parent = renderer.current_node
+
+        if not hasattr(self.reporter, "get_source_and_line"):
+            # In docutils this is set by `RSTState.runtime_init`
+            self.reporter.get_source_and_line = lambda l: (self.document["source"], l)
+
         self.rfc_url = "rfc%d.html"
 
     def problematic(
         self, text: str, rawsource: str, message: nodes.system_message
     ) -> nodes.problematic:
+        """Record a system message from parsing."""
         msgid = self.document.set_id(message, self.parent)
-        problematic = nodes.problematic(rawsource, rawsource, refid=msgid)
+        problematic = nodes.problematic(rawsource, text, refid=msgid)
         prbid = self.document.set_id(problematic)
         message.add_backref(prbid)
         return problematic
 
-    # TODO add parse method
+    def parse(
+        self, text: str, lineno: int, memo: Any, parent: nodes.Node
+    ) -> tuple[list[nodes.Node], list[nodes.system_message]]:
+        """Parse the text and return a list of nodes."""
+        # note the only place this is normally called,
+        # is by `RSTState.inline_text`, or in directives: `self.state.inline_text`,
+        # and there the state parses its own parent
+        # self.reporter = memo.reporter
+        # self.document = memo.document
+        # self.language = memo.language
+        with self._renderer.current_node_context(parent):
+            # the parent is never actually appended to though,
+            # so we make a temporary parent to parse into
+            container = nodes.Element()
+            with self._renderer.current_node_context(container):
+                self._renderer.nested_render_text(text, lineno, inline=True)
+
+        return container.children, []
 
     def __getattr__(self, name: str):
         """This method is only be called if the attribute requested has not
@@ -64,7 +88,7 @@ class MockInliner:
                 cls=type(self).__name__, name=name
             )
             raise MockingError(msg).with_traceback(sys.exc_info()[2])
-        msg = "{cls} has no attribute {name}".format(cls=type(self).__name__, name=name)
+        msg = f"{type(self).__name__} has no attribute {name}"
         raise MockingError(msg).with_traceback(sys.exc_info()[2])
 
 
@@ -78,8 +102,8 @@ class MockState:
 
     def __init__(
         self,
-        renderer: "DocutilsRenderer",
-        state_machine: "MockStateMachine",
+        renderer: DocutilsRenderer,
+        state_machine: MockStateMachine,
         lineno: int,
     ):
         self._renderer = renderer
@@ -87,13 +111,13 @@ class MockState:
         self.document = renderer.document
         self.reporter = renderer.document.reporter
         self.state_machine = state_machine
-        self.inliner = MockInliner(renderer, lineno)
+        self.inliner = MockInliner(renderer)
 
         class Struct:
             document = self.document
             reporter = self.document.reporter
             language = renderer.language_module_rst
-            title_styles: List[str] = []
+            title_styles: list[str] = []
             section_level = max(renderer._level_to_elem)
             section_bubble_up_kludge = False
             inliner = self.inliner
@@ -104,9 +128,9 @@ class MockState:
         self,
         content: StringList,
         line_offset: int,
-        directive: Type[Directive],
+        directive: type[Directive],
         option_presets: dict,
-    ) -> Tuple[list, dict, StringList, int]:
+    ) -> tuple[list, dict, StringList, int]:
         """Parse the full directive text
 
         :returns: (arguments, options, content, content_offset)
@@ -114,14 +138,14 @@ class MockState:
         if option_presets:
             raise MockingError("parse_directive_block: option_presets not implemented")
         # TODO should argument_str always be ""?
-        arguments, options, body_lines = parse_directive_text(
+        arguments, options, body_lines, content_offset = parse_directive_text(
             directive, "", "\n".join(content)
         )
         return (
             arguments,
             options,
             StringList(body_lines, source=content.source),
-            line_offset + len(content) - len(body_lines),
+            line_offset + content_offset,
         )
 
     def nested_parse(
@@ -133,19 +157,24 @@ class MockState:
         state_machine_class=None,
         state_machine_kwargs=None,
     ) -> None:
-        """Perform a nested parse of the input block, with ``node`` as the parent."""
-        sm_match_titles = self.state_machine.match_titles
-        render_match_titles = self._renderer.md_env.get("match_titles", None)
-        self.state_machine.match_titles = self._renderer.md_env[
-            "match_titles"
-        ] = match_titles
+        """Perform a nested parse of the input block, with ``node`` as the parent.
 
+        :param block: The block of lines to parse.
+        :param input_offset: The offset of the first line of block,
+            to the starting line of the state (i.e. directive).
+        :param node: The parent node to attach the parsed content to.
+        :param match_titles: Whether to to allow the parsing of headings
+            (normally this is false,
+            since nested heading would break the document structure)
+        """
+        sm_match_titles = self.state_machine.match_titles
         with self._renderer.current_node_context(node):
             self._renderer.nested_render_text(
-                "\n".join(block), self._lineno + input_offset
+                "\n".join(block),
+                self._lineno + input_offset,
+                allow_headings=match_titles,
             )
         self.state_machine.match_titles = sm_match_titles
-        self._renderer.md_env["match_titles"] = render_match_titles
 
     def parse_target(self, block, block_text, lineno: int):
         """
@@ -162,43 +191,17 @@ class MockState:
 
     def inline_text(
         self, text: str, lineno: int
-    ) -> Tuple[List[nodes.Element], List[nodes.Element]]:
+    ) -> tuple[list[nodes.Element], list[nodes.Element]]:
         """Parse text with only inline rules.
 
-        :return: (list of nodes, list of messages)
-
+        :returns: (list of nodes, list of messages)
         """
-        # TODO return messages?
-        messages: List[nodes.Element] = []
-        paragraph = nodes.paragraph("")
-
-        tokens = self._renderer.md.parseInline(text, self._renderer.md_env)
-        for token in tokens:
-            if token.map:
-                token.map = [token.map[0] + lineno, token.map[1] + lineno]
-
-        # here we instantiate a new renderer,
-        # so that the nested parse does not effect the current renderer,
-        # but we use the same env, so that link references, etc
-        # are added to the global parse.
-        from myst_parser.docutils_renderer import DocutilsRenderer
-
-        nested_renderer = DocutilsRenderer(self._renderer.md)
-        options = {k: v for k, v in self._renderer.config.items()}
-        options.update(
-            {
-                "document": self.document,
-                "current_node": paragraph,
-                "output_footnotes": False,
-            }
-        )
-        nested_renderer.render(tokens, options, self._renderer.md_env)
-        return paragraph.children, messages
+        return self.inliner.parse(text, lineno, self.memo, self._renderer.current_node)
 
     # U+2014 is an em-dash:
     attribution_pattern = re.compile("^((?:---?(?!-)|\u2014) *)(.+)")
 
-    def block_quote(self, lines: List[str], line_offset: int) -> List[nodes.Element]:
+    def block_quote(self, lines: list[str], line_offset: int) -> list[nodes.Element]:
         """Parse a block quote, which is a block of text,
         followed by an (optional) attribution.
 
@@ -283,7 +286,7 @@ class MockStateMachine:
     This is parsed to the `Directives.run()` method.
     """
 
-    def __init__(self, renderer: "DocutilsRenderer", lineno: int):
+    def __init__(self, renderer: DocutilsRenderer, lineno: int):
         self._renderer = renderer
         self._lineno = lineno
         self.document = renderer.document
@@ -292,11 +295,11 @@ class MockStateMachine:
         self.node: nodes.Element = renderer.current_node
         self.match_titles: bool = True
 
-    def get_source(self, lineno: Optional[int] = None):
+    def get_source(self, lineno: int | None = None):
         """Return document source path."""
         return self.document["source"]
 
-    def get_source_and_line(self, lineno: Optional[int] = None):
+    def get_source_and_line(self, lineno: int | None = None):
         """Return (source path, line) tuple for current or given line number."""
         return self.document["source"], lineno or self._lineno
 
@@ -309,7 +312,7 @@ class MockStateMachine:
                 cls=type(self).__name__, name=name
             )
             raise MockingError(msg).with_traceback(sys.exc_info()[2])
-        msg = "{cls} has no attribute {name}".format(cls=type(self).__name__, name=name)
+        msg = f"{type(self).__name__} has no attribute {name}"
         raise MockingError(msg).with_traceback(sys.exc_info()[2])
 
 
@@ -323,12 +326,12 @@ class MockIncludeDirective:
 
     def __init__(
         self,
-        renderer: "DocutilsRenderer",
+        renderer: DocutilsRenderer,
         name: str,
         klass: Include,
         arguments: list,
         options: dict,
-        body: List[str],
+        body: list[str],
         lineno: int,
     ):
         self.renderer = renderer
@@ -340,12 +343,12 @@ class MockIncludeDirective:
         self.body = body
         self.lineno = lineno
 
-    def run(self) -> List[nodes.Element]:
+    def run(self) -> list[nodes.Element]:
 
         from docutils.parsers.rst.directives.body import CodeBlock, NumberLines
 
         if not self.document.settings.file_insertion_enabled:
-            raise DirectiveError(2, 'Directive "{}" disabled.'.format(self.name))
+            raise DirectiveError(2, f'Directive "{self.name}" disabled.')
 
         source_dir = Path(self.document["source"]).absolute().parent
         include_arg = "".join([s.strip() for s in self.arguments[0].splitlines()])
@@ -457,21 +460,23 @@ class MockIncludeDirective:
             self.renderer.reporter.source = str(path)
             self.renderer.reporter.get_source_and_line = lambda l: (str(path), l)
             if "relative-images" in self.options:
-                self.renderer.config["relative-images"] = os.path.relpath(
+                self.renderer.md_env["relative-images"] = os.path.relpath(
                     path.parent, source_dir
                 )
             if "relative-docs" in self.options:
-                self.renderer.config["relative-docs"] = (
+                self.renderer.md_env["relative-docs"] = (
                     self.options["relative-docs"],
                     source_dir,
                     path.parent,
                 )
-            self.renderer.nested_render_text(file_content, startline + 1)
+            self.renderer.nested_render_text(
+                file_content, startline + 1, allow_headings=True
+            )
         finally:
             self.renderer.document["source"] = source
             self.renderer.reporter.source = rsource
-            self.renderer.config.pop("relative-images", None)
-            self.renderer.config.pop("relative-docs", None)
+            self.renderer.md_env.pop("relative-images", None)
+            self.renderer.md_env.pop("relative-docs", None)
             if line_func is not None:
                 self.renderer.reporter.get_source_and_line = line_func
             else:
