@@ -3,4 +3,4 @@
    .. include::  path/to/file.md
       :parser: myst_parser.sphinx_
 """
-from myst_parser.sphinx_parser import MystParser as Parser  # noqa: F401
+from myst_parser.parsers.sphinx_ import MystParser as Parser  # noqa: F401
