@@ -18,7 +18,10 @@ SOURCE_DIR = os.path.abspath(os.path.join(os.path.dirname(__file__), "sourcedirs
 
 
 @pytest.mark.sphinx(
-    buildername="html", srcdir=os.path.join(SOURCE_DIR, "basic"), freshenv=True
+    buildername="html",
+    srcdir=os.path.join(SOURCE_DIR, "basic"),
+    freshenv=True,
+    confoverrides={"myst_enable_extensions": ["dollarmath"]},
 )
 def test_basic(
     app,
@@ -26,7 +29,6 @@ def test_basic(
     warning,
     get_sphinx_app_doctree,
     get_sphinx_app_output,
-    remove_sphinx_builds,
 ):
     """basic test."""
     app.build()
@@ -35,19 +37,19 @@ def test_basic(
     warnings = warning.getvalue().strip()
     assert warnings == ""
 
-    get_sphinx_app_doctree(
-        app,
-        docname="content",
-        regress=True,
-        regress_ext=f".sphinx{sphinx.version_info[0]}.xml",
-    )
-    get_sphinx_app_doctree(
-        app,
-        docname="content",
-        resolve=True,
-        regress=True,
-        regress_ext=f".sphinx{sphinx.version_info[0]}.xml",
-    )
+    try:
+        get_sphinx_app_doctree(
+            app,
+            docname="content",
+            regress=True,
+        )
+    finally:
+        get_sphinx_app_doctree(
+            app,
+            docname="content",
+            resolve=True,
+            regress=True,
+        )
     get_sphinx_app_output(
         app,
         filename="content.html",
@@ -67,7 +69,8 @@ def test_basic(
         "date": "2/12/1985",
         "copyright": "MIT",
         "other": "Something else",
-        "wordcount": {"minutes": 0, "words": 53},
+        "other_dict": '{"key": "value"}',
+        "wordcount": {"minutes": 0, "words": 57},
     }
 
 
@@ -75,6 +78,7 @@ def test_basic(
     buildername="html",
     srcdir=os.path.join(SOURCE_DIR, "references"),
     freshenv=True,
+    confoverrides={"myst_enable_extensions": ["dollarmath"]},
 )
 def test_references(
     app,
@@ -82,7 +86,6 @@ def test_references(
     warning,
     get_sphinx_app_doctree,
     get_sphinx_app_output,
-    remove_sphinx_builds,
 ):
     """Test reference resolution."""
     app.build()
@@ -94,13 +97,15 @@ def test_references(
     try:
         get_sphinx_app_doctree(app, docname="index", regress=True)
     finally:
-        get_sphinx_app_doctree(app, docname="index", resolve=True, regress=True)
-    get_sphinx_app_output(
-        app,
-        filename="index.html",
-        regress_html=True,
-        regress_ext=f".sphinx{sphinx.version_info[0]}.html",
-    )
+        try:
+            get_sphinx_app_doctree(app, docname="index", resolve=True, regress=True)
+        finally:
+            get_sphinx_app_output(
+                app,
+                filename="index.html",
+                regress_html=True,
+                replace={"Permalink to this headline": "Permalink to this heading"},
+            )
 
 
 @pytest.mark.sphinx(
@@ -115,7 +120,6 @@ def test_references_singlehtml(
     warning,
     get_sphinx_app_doctree,
     get_sphinx_app_output,
-    remove_sphinx_builds,
 ):
     """Test reference resolution for singlehtml builds."""
     app.build()
@@ -150,7 +154,7 @@ def test_references_singlehtml(
         filename="index.html",
         buildername="singlehtml",
         regress_html=True,
-        regress_ext=f".sphinx{sphinx.version_info[0]}.html",
+        replace={"Permalink to this headline": "Permalink to this heading"},
     )
 
 
@@ -165,7 +169,6 @@ def test_heading_slug_func(
     warning,
     get_sphinx_app_doctree,
     get_sphinx_app_output,
-    remove_sphinx_builds,
 ):
     """Test heading_slug_func configuration."""
     app.build()
@@ -182,7 +185,7 @@ def test_heading_slug_func(
         app,
         filename="index.html",
         regress_html=True,
-        regress_ext=f".sphinx{sphinx.version_info[0]}.html",
+        replace={"Permalink to this headline": "Permalink to this heading"},
     )
 
 
@@ -197,11 +200,10 @@ def test_extended_syntaxes(
     warning,
     get_sphinx_app_doctree,
     get_sphinx_app_output,
-    remove_sphinx_builds,
     monkeypatch,
 ):
     """test setting addition configuration values."""
-    from myst_parser.sphinx_renderer import SphinxRenderer
+    from myst_parser.mdit_to_docutils.sphinx_ import SphinxRenderer
 
     monkeypatch.setattr(SphinxRenderer, "_random_label", lambda self: "mock-uuid")
     app.build()
@@ -214,14 +216,13 @@ def test_extended_syntaxes(
             app,
             docname="index",
             regress=True,
-            regress_ext=f".sphinx{sphinx.version_info[0]}.xml",
         )
     finally:
         get_sphinx_app_output(
             app,
             filename="index.html",
             regress_html=True,
-            regress_ext=f".sphinx{sphinx.version_info[0]}.html",
+            replace={"Permalink to this headline": "Permalink to this heading"},
         )
 
 
@@ -234,7 +235,6 @@ def test_includes(
     warning,
     get_sphinx_app_doctree,
     get_sphinx_app_output,
-    remove_sphinx_builds,
 ):
     """Test of include directive."""
     app.build()
@@ -248,7 +248,6 @@ def test_includes(
             app,
             docname="index",
             regress=True,
-            regress_ext=f".sphinx{sphinx.version_info[0]}.xml",
             # fix for Windows CI
             replace={
                 r"subfolder\example2.jpg": "subfolder/example2.jpg",
@@ -261,8 +260,8 @@ def test_includes(
             app,
             filename="index.html",
             regress_html=True,
-            regress_ext=f".sphinx{sphinx.version_info[0]}.html",
             replace={
+                "Permalink to this headline": "Permalink to this heading",
                 r"'subfolder\\example2'": "'subfolder/example2'",
                 r'uri="subfolder\\example2"': 'uri="subfolder/example2"',
                 "_images/example21.jpg": "_images/example2.jpg",
@@ -284,8 +283,6 @@ def test_include_from_rst(
     status,
     warning,
     get_sphinx_app_doctree,
-    get_sphinx_app_output,
-    remove_sphinx_builds,
 ):
     """Test of include directive inside RST file."""
     app.build()
@@ -302,6 +299,10 @@ def test_include_from_rst(
     )
 
 
+@pytest.mark.skipif(
+    __version_info__ < VersionInfo(0, 19, 0, "final", 0, True),
+    reason="Footnote HTML changed in docutils 0.19",
+)
 @pytest.mark.sphinx(
     buildername="html", srcdir=os.path.join(SOURCE_DIR, "footnotes"), freshenv=True
 )
@@ -311,7 +312,6 @@ def test_footnotes(
     warning,
     get_sphinx_app_doctree,
     get_sphinx_app_output,
-    remove_sphinx_builds,
 ):
     """Test of include directive."""
     app.build()
@@ -342,7 +342,6 @@ def test_commonmark_only(
     warning,
     get_sphinx_app_doctree,
     get_sphinx_app_output,
-    remove_sphinx_builds,
 ):
     """test setting addition configuration values."""
     app.build()
@@ -357,7 +356,7 @@ def test_commonmark_only(
             app,
             filename="index.html",
             regress_html=True,
-            regress_ext=f".sphinx{sphinx.version_info[0]}.html",
+            replace={"Permalink to this headline": "Permalink to this heading"},
         )
 
 
@@ -372,7 +371,6 @@ def test_substitutions(
     warning,
     get_sphinx_app_doctree,
     get_sphinx_app_output,
-    remove_sphinx_builds,
     file_regression,
 ):
     """test setting addition configuration values."""
@@ -399,7 +397,6 @@ def test_gettext(
     status,
     warning,
     get_sphinx_app_output,
-    remove_sphinx_builds,
     file_regression,
 ):
     """Test gettext message extraction."""
@@ -412,7 +409,7 @@ def test_gettext(
     output = re.sub(r"POT-Creation-Date: [0-9: +-]+", "POT-Creation-Date: ", output)
     output = re.sub(r"Copyright \(C\) [0-9]{4}", "Copyright (C) XXXX", output)
 
-    file_regression.check(output, extension=f".sphinx{sphinx.version_info[0]}.pot")
+    file_regression.check(output, extension=".pot")
 
 
 @pytest.mark.sphinx(
@@ -427,7 +424,6 @@ def test_gettext_html(
     warning,
     get_sphinx_app_doctree,
     get_sphinx_app_output,
-    remove_sphinx_builds,
 ):
     """Test gettext message extraction."""
     app.build()
@@ -440,7 +436,6 @@ def test_gettext_html(
             app,
             docname="index",
             regress=True,
-            regress_ext=f".sphinx{sphinx.version_info[0]}.xml",
         )
     finally:
         get_sphinx_app_doctree(
@@ -448,7 +443,6 @@ def test_gettext_html(
             docname="index",
             resolve=True,
             regress=True,
-            regress_ext=f".sphinx{sphinx.version_info[0]}.xml",
         )
     get_sphinx_app_output(
         app,
@@ -477,7 +471,6 @@ def test_gettext_additional_targets(
     status,
     warning,
     get_sphinx_app_output,
-    remove_sphinx_builds,
     file_regression,
 ):
     """Test gettext message extraction."""
@@ -490,17 +483,19 @@ def test_gettext_additional_targets(
     output = re.sub(r"POT-Creation-Date: [0-9: +-]+", "POT-Creation-Date: ", output)
     output = re.sub(r"Copyright \(C\) [0-9]{4}", "Copyright (C) XXXX", output)
 
-    file_regression.check(output, extension=f".sphinx{sphinx.version_info[0]}.pot")
+    file_regression.check(output, extension=".pot")
 
 
 @pytest.mark.sphinx(
-    buildername="html", srcdir=os.path.join(SOURCE_DIR, "mathjax"), freshenv=True
+    buildername="html",
+    srcdir=os.path.join(SOURCE_DIR, "mathjax"),
+    freshenv=True,
+    confoverrides={"myst_enable_extensions": ["dollarmath"]},
 )
 def test_mathjax_warning(
     app,
     status,
     warning,
-    remove_sphinx_builds,
 ):
     """Test mathjax config override warning."""
     app.build()
@@ -523,7 +518,6 @@ def test_fieldlist_extension(
     warning,
     get_sphinx_app_doctree,
     get_sphinx_app_output,
-    remove_sphinx_builds,
 ):
     """test setting addition configuration values."""
     app.build()
@@ -536,7 +530,14 @@ def test_fieldlist_extension(
             app,
             docname="index",
             regress=True,
-            regress_ext=f".sphinx{sphinx.version_info[0]}.xml",
+            # changed in:
+            # https://www.sphinx-doc.org/en/master/changes.html#release-4-4-0-released-jan-17-2022
+            replace={
+                (
+                    '<literal_strong py:class="True" '
+                    'py:module="True" refspecific="True">'
+                ): "<literal_strong>"
+            },
         )
     finally:
         get_sphinx_app_output(
@@ -545,3 +546,20 @@ def test_fieldlist_extension(
             regress_html=True,
             regress_ext=f".sphinx{sphinx.version_info[0]}.html",
         )
+
+
+@pytest.mark.sphinx(
+    buildername="texinfo",
+    srcdir=os.path.join(SOURCE_DIR, "texi_table"),
+    freshenv=True,
+)
+def test_texinfo_table(
+    app,
+    status,
+    warning,
+):
+    """Test that tables can be built with the Texinfo builder."""
+    app.build()
+    assert "build succeeded" in status.getvalue()  # Build succeeded
+    warnings = warning.getvalue().strip()
+    assert warnings == ""
